**Example 1: 删除设备影子接口**



Input: 

```
tccli iotcloud DeleteDeviceShadow --cli-unfold-argument  \
    --ProductId ABCDE12345 \
    --DeviceName abc
```

Output: 
```
{
    "Response": {
        "RequestId": "xxxxxxxxxxxxxxxxxxxxxxx"
    }
}
```

